@@ -3,10 +3,13 @@ class BoardGameGeekError(Exception):
     pass
 
 
-class BoardGameGeekAPIRetryError(BoardGameGeekError):
-    pass
-
-
 class BoardGameGeekAPIError(BoardGameGeekError):
     pass
 
+
+class BoardGameGeekAPIRetryError(BoardGameGeekAPIError):
+    pass
+
+
+class BoardGameGeekAPINonXMLError(BoardGameGeekAPIError):
+    pass
